pub enum EstimateMode {
NoPriority,
LowPriority,
MediumPriority,
HighPriority,
}Expand description
The fee estimate mode.
Variants
NoPriority
No priority, expect the transaction to be committed in 1 hour.
LowPriority
Low priority, expect the transaction to be committed in 30 minutes.
MediumPriority
Medium priority, expect the transaction to be committed in 10 minutes.
HighPriority
High priority, expect the transaction to be committed as soon as possible.