Struct ckb_jsonrpc_types::request::Notification [−][src]
Represents jsonrpc request which is a notification.
Fields
jsonrpc: Option<Version>A String specifying the version of the JSON-RPC protocol.
method: StringA String containing the name of the method to be invoked.
params: ParamsA Structured value that holds the parameter values to be used during the invocation of the method. This member MAY be omitted.