Struct ckb_jsonrpc_types::HeaderView [−][src]
pub struct HeaderView {
pub inner: Header,
pub hash: H256,
}Expand description
The JSON view of a Header.
This structure is serialized into a JSON object with field hash and all the fields in
Header.
Examples
{
"compact_target": "0x1e083126",
"dao": "0xb5a3e047474401001bc476b9ee573000c0c387962a38000000febffacf030000",
"epoch": "0x7080018000001",
"hash": "0xa5f5c85987a15de25661e5a214f2c1449cd803f071acc7999820f25246471f40",
"nonce": "0x0",
"number": "0x400",
"parent_hash": "0xae003585fa15309b30b31aed3dcf385e9472c3c3e93746a6c4540629a6a1ed2d",
"proposals_hash": "0x0000000000000000000000000000000000000000000000000000000000000000",
"timestamp": "0x5cd2b117",
"transactions_root": "0xc47d5b78b3c4c4c853e2a32810818940d0ee403423bea9ec7b8e566d9595206c",
"uncles_hash": "0x0000000000000000000000000000000000000000000000000000000000000000",
"version": "0x0"
}Fields
inner: HeaderAll the fields in Header are included in HeaderView in JSON.
hash: H256The header hash. It is also called the block hash.