pub struct Network {
pub interface_name: String,
pub received: u64,
pub total_received: u64,
pub transmitted: u64,
pub total_transmitted: u64,
}Expand description
Getting volume of received and transmitted data.
Fields
interface_name: StringReturns network interface name
received: u64Returns the number of received bytes since the last refresh.
total_received: u64Returns the total number of received bytes.
transmitted: u64Returns the number of transmitted bytes since the last refresh.
total_transmitted: u64Returns the total number of transmitted bytes.