pub struct OutPoint {
pub tx_hash: H256,
pub index: Uint32,
}Expand description
Reference to a cell via transaction hash and output index.
Examples
{
"index": "0x0",
"tx_hash": "0x365698b50ca0da75dca2c87f9e7b563811d3b5813736b8cc62cc3b106faceb17"
}Fields
tx_hash: H256Transaction hash in which the cell is an output.
index: Uint32The output index of the cell in the transaction specified by tx_hash.