TerminalPoolInfo

Struct TerminalPoolInfo 

pub struct TerminalPoolInfo {
    pub pending: Uint64,
    pub proposed: Uint64,
    pub orphan: Uint64,
    pub committing: Uint64,
    pub total_recent_reject_num: Uint64,
    pub total_tx_size: Uint64,
    pub total_tx_cycles: Uint64,
    pub max_tx_pool_size: Uint64,
    pub last_txs_updated_at: Timestamp,
}
Transaction pool information.

Fields

pending: Uint64

Count of transactions in the pending state.

The pending transactions must be proposed in a new block first.

proposed: Uint64

Count of transactions in the proposed state.

The proposed transactions are ready to be committed in the new block after the block tip_hash.

orphan: Uint64

Count of orphan transactions.

An orphan transaction has an input cell from the transaction which is neither in the chain nor in the transaction pool.

committing: Uint64

Count of committing transactions.

The Committing transactions refer to transactions that have been packaged into the block_template and are awaiting mining into a block.

total_recent_reject_num: Uint64

Total count of recent reject transactions by pool

total_tx_size: Uint64

Total size of transactions bytes in the pool of all the different kinds of states (excluding orphan transactions).

total_tx_cycles: Uint64

Total consumed VM cycles of all the transactions in the pool (excluding orphan transactions).

max_tx_pool_size: Uint64

Total limit on the size of transactions in the tx-pool

last_txs_updated_at: Timestamp

Last updated time. This is the Unix timestamp in milliseconds.